Class: Aws::SupportApp::Types::ListSlackChannelConfigurationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-supportapp/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the results of a search are large, the API only returns a portion of the results and includes a nextToken pagination token in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When the API returns the last set of results, the response doesn't include a pagination token value.

Returns:

  • (String)


238
239
240
241
242
# File 'lib/aws-sdk-supportapp/types.rb', line 238

class ListSlackChannelConfigurationsRequest < Struct.new(
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end