Class: Aws::SupportApp::Types::SlackChannelConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-supportapp/types.rb

Overview

The configuration for a Slack channel that you added for your Amazon Web Services account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_id ⇒ String

The channel ID in Slack. This ID identifies a channel within a Slack workspace.

Returns:

  • (String)


432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-supportapp/types.rb', line 432

class SlackChannelConfiguration < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#channel_name ⇒ String

The name of the Slack channel that you configured with the Amazon Web Services Support App for your Amazon Web Services account.

Returns:

  • (String)


432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-supportapp/types.rb', line 432

class SlackChannelConfiguration < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#channel_role_arn ⇒ String

The Amazon Resource Name (ARN) of an IAM role that you want to use to perform operations on Amazon Web Services. For more information, see Managing access to the Amazon Web Services Support App in the Amazon Web Services Support User Guide.

Returns:

  • (String)


432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-supportapp/types.rb', line 432

class SlackChannelConfiguration < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_add_correspondence_to_case ⇒ Boolean

Whether you want to get notified when a support case has a new correspondence.

Returns:

  • (Boolean)


432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-supportapp/types.rb', line 432

class SlackChannelConfiguration < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_case_severity ⇒ String

The case severity for a support case that you want to receive notifications.

Returns:

  • (String)


432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-supportapp/types.rb', line 432

class SlackChannelConfiguration < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_create_or_reopen_case ⇒ Boolean

Whether you want to get notified when a support case is created or reopened.

Returns:

  • (Boolean)


432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-supportapp/types.rb', line 432

class SlackChannelConfiguration < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_resolve_case ⇒ Boolean

Whether you want to get notified when a support case is resolved.

Returns:

  • (Boolean)


432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-supportapp/types.rb', line 432

class SlackChannelConfiguration < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#team_id ⇒ String

The team ID in Slack. This ID uniquely identifies a Slack workspace, such as T012ABCDEFG.

Returns:

  • (String)


432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-supportapp/types.rb', line 432

class SlackChannelConfiguration < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end