Class: Aws::SupportApp::Types::UpdateSlackChannelConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-supportapp/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_id ⇒ String

The channel ID in Slack. This ID identifies a channel within a Slack workspace.

Returns:

  • (String)


541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-supportapp/types.rb', line 541

class UpdateSlackChannelConfigurationRequest < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#channel_name ⇒ String

The Slack channel name that you want to update.

Returns:

  • (String)


541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-supportapp/types.rb', line 541

class UpdateSlackChannelConfigurationRequest < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#channel_role_arn ⇒ String

The Amazon Resource Name (ARN) of an IAM role that you want to use to perform operations on Amazon Web Services. For more information, see Managing access to the Amazon Web Services Support App in the Amazon Web Services Support User Guide.

Returns:

  • (String)


541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-supportapp/types.rb', line 541

class UpdateSlackChannelConfigurationRequest < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_add_correspondence_to_case ⇒ Boolean

Whether you want to get notified when a support case has a new correspondence.

Returns:

  • (Boolean)


541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-supportapp/types.rb', line 541

class UpdateSlackChannelConfigurationRequest < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_case_severity ⇒ String

The case severity for a support case that you want to receive notifications.

If you specify high or all, at least one of the following parameters must be true:

  • notifyOnAddCorrespondenceToCase

  • notifyOnCreateOrReopenCase

  • notifyOnResolveCase

If you specify none, any of the following parameters that you specify in your request must be false:

  • notifyOnAddCorrespondenceToCase

  • notifyOnCreateOrReopenCase

  • notifyOnResolveCase

If you don't specify these parameters in your request, the Amazon Web Services Support App uses the current values by default.

Returns:

  • (String)


541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-supportapp/types.rb', line 541

class UpdateSlackChannelConfigurationRequest < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_create_or_reopen_case ⇒ Boolean

Whether you want to get notified when a support case is created or reopened.

Returns:

  • (Boolean)


541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-supportapp/types.rb', line 541

class UpdateSlackChannelConfigurationRequest < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_resolve_case ⇒ Boolean

Whether you want to get notified when a support case is resolved.

Returns:

  • (Boolean)


541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-supportapp/types.rb', line 541

class UpdateSlackChannelConfigurationRequest < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#team_id ⇒ String

The team ID in Slack. This ID uniquely identifies a Slack workspace, such as T012ABCDEFG.

Returns:

  • (String)


541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-supportapp/types.rb', line 541

class UpdateSlackChannelConfigurationRequest < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end