Class: Aws::SupportApp::Types::UpdateSlackChannelConfigurationResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-supportapp/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_id ⇒ String

The channel ID in Slack. This ID identifies a channel within a Slack workspace.

Returns:

  • (String)


601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/aws-sdk-supportapp/types.rb', line 601

class UpdateSlackChannelConfigurationResult < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#channel_name ⇒ String

The name of the Slack channel that you configure for the Amazon Web Services Support App.

Returns:

  • (String)


601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/aws-sdk-supportapp/types.rb', line 601

class UpdateSlackChannelConfigurationResult < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#channel_role_arn ⇒ String

The Amazon Resource Name (ARN) of an IAM role that you want to use to perform operations on Amazon Web Services. For more information, see Managing access to the Amazon Web Services Support App in the Amazon Web Services Support User Guide.

Returns:

  • (String)


601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/aws-sdk-supportapp/types.rb', line 601

class UpdateSlackChannelConfigurationResult < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_add_correspondence_to_case ⇒ Boolean

Whether you want to get notified when a support case has a new correspondence.

Returns:

  • (Boolean)


601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/aws-sdk-supportapp/types.rb', line 601

class UpdateSlackChannelConfigurationResult < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_case_severity ⇒ String

The case severity for a support case that you want to receive notifications.

Returns:

  • (String)


601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/aws-sdk-supportapp/types.rb', line 601

class UpdateSlackChannelConfigurationResult < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_create_or_reopen_case ⇒ Boolean

Whether you want to get notified when a support case is created or reopened.

Returns:

  • (Boolean)


601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/aws-sdk-supportapp/types.rb', line 601

class UpdateSlackChannelConfigurationResult < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#notify_on_resolve_case ⇒ Boolean

Whether you want to get notified when a support case is resolved.

Returns:

  • (Boolean)


601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/aws-sdk-supportapp/types.rb', line 601

class UpdateSlackChannelConfigurationResult < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end

#team_id ⇒ String

The team ID in Slack. This ID uniquely identifies a Slack workspace, such as T012ABCDEFG.

Returns:

  • (String)


601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/aws-sdk-supportapp/types.rb', line 601

class UpdateSlackChannelConfigurationResult < Struct.new(
  :channel_id,
  :channel_name,
  :channel_role_arn,
  :notify_on_add_correspondence_to_case,
  :notify_on_case_severity,
  :notify_on_create_or_reopen_case,
  :notify_on_resolve_case,
  :team_id)
  SENSITIVE = []
  include Aws::Structure
end