Class: Aws::SupportApp::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SupportApp::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-supportapp/client.rb
Overview
An API client for SupportApp. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SupportApp::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_slack_channel_configuration(params = {}) ⇒ Struct
Creates a Slack channel configuration for your Amazon Web Services account.
-
#delete_account_alias(params = {}) ⇒ Struct
Deletes an alias for an Amazon Web Services account ID.
-
#delete_slack_channel_configuration(params = {}) ⇒ Struct
Deletes a Slack channel configuration from your Amazon Web Services account.
-
#delete_slack_workspace_configuration(params = {}) ⇒ Struct
Deletes a Slack workspace configuration from your Amazon Web Services account.
-
#get_account_alias(params = {}) ⇒ Types::GetAccountAliasResult
Retrieves the alias from an Amazon Web Services account ID.
-
#list_slack_channel_configurations(params = {}) ⇒ Types::ListSlackChannelConfigurationsResult
Lists the Slack channel configurations for an Amazon Web Services account.
-
#list_slack_workspace_configurations(params = {}) ⇒ Types::ListSlackWorkspaceConfigurationsResult
Lists the Slack workspace configurations for an Amazon Web Services account.
-
#put_account_alias(params = {}) ⇒ Struct
Creates or updates an individual alias for each Amazon Web Services account ID.
-
#register_slack_workspace_for_organization(params = {}) ⇒ Types::RegisterSlackWorkspaceForOrganizationResult
Registers a Slack workspace for your Amazon Web Services account.
-
#update_slack_channel_configuration(params = {}) ⇒ Types::UpdateSlackChannelConfigurationResult
Updates the configuration for a Slack channel, such as case update notifications.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-supportapp/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
997 998 999 |
# File 'lib/aws-sdk-supportapp/client.rb', line 997 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1000 1001 1002 |
# File 'lib/aws-sdk-supportapp/client.rb', line 1000 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-supportapp/client.rb', line 970 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SupportApp') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-supportapp' context[:gem_version] = '1.47.0' Seahorse::Client::Request.new(handlers, context) end |
#create_slack_channel_configuration(params = {}) ⇒ Struct
Creates a Slack channel configuration for your Amazon Web Services account.
<note markdown=“1”> * You can add up to 5 Slack workspaces for your account.
-
You can add up to 20 Slack channels for your account.
</note>
A Slack channel can have up to 100 Amazon Web Services accounts. This means that only 100 accounts can add the same Slack channel to the Amazon Web Services Support App. We recommend that you only add the accounts that you need to manage support cases for your organization. This can reduce the notifications about case updates that you receive in the Slack channel.
<note markdown=“1”> We recommend that you choose a private Slack channel so that only members in that channel have read and write access to your support cases. Anyone in your Slack channel can create, update, or resolve support cases for your account. Users require an invitation to join private channels.
</note>
580 581 582 583 |
# File 'lib/aws-sdk-supportapp/client.rb', line 580 def create_slack_channel_configuration(params = {}, = {}) req = build_request(:create_slack_channel_configuration, params) req.send_request() end |
#delete_account_alias(params = {}) ⇒ Struct
Deletes an alias for an Amazon Web Services account ID. The alias appears in the Amazon Web Services Support App page of the Amazon Web Services Support Center. The alias also appears in Slack messages from the Amazon Web Services Support App.
596 597 598 599 |
# File 'lib/aws-sdk-supportapp/client.rb', line 596 def delete_account_alias(params = {}, = {}) req = build_request(:delete_account_alias, params) req.send_request() end |
#delete_slack_channel_configuration(params = {}) ⇒ Struct
Deletes a Slack channel configuration from your Amazon Web Services account. This operation doesn’t delete your Slack channel.
625 626 627 628 |
# File 'lib/aws-sdk-supportapp/client.rb', line 625 def delete_slack_channel_configuration(params = {}, = {}) req = build_request(:delete_slack_channel_configuration, params) req.send_request() end |
#delete_slack_workspace_configuration(params = {}) ⇒ Struct
Deletes a Slack workspace configuration from your Amazon Web Services account. This operation doesn’t delete your Slack workspace.
649 650 651 652 |
# File 'lib/aws-sdk-supportapp/client.rb', line 649 def delete_slack_workspace_configuration(params = {}, = {}) req = build_request(:delete_slack_workspace_configuration, params) req.send_request() end |
#get_account_alias(params = {}) ⇒ Types::GetAccountAliasResult
Retrieves the alias from an Amazon Web Services account ID. The alias appears in the Amazon Web Services Support App page of the Amazon Web Services Support Center. The alias also appears in Slack messages from the Amazon Web Services Support App.
671 672 673 674 |
# File 'lib/aws-sdk-supportapp/client.rb', line 671 def get_account_alias(params = {}, = {}) req = build_request(:get_account_alias, params) req.send_request() end |
#list_slack_channel_configurations(params = {}) ⇒ Types::ListSlackChannelConfigurationsResult
Lists the Slack channel configurations for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
717 718 719 720 |
# File 'lib/aws-sdk-supportapp/client.rb', line 717 def list_slack_channel_configurations(params = {}, = {}) req = build_request(:list_slack_channel_configurations, params) req.send_request() end |
#list_slack_workspace_configurations(params = {}) ⇒ Types::ListSlackWorkspaceConfigurationsResult
Lists the Slack workspace configurations for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
758 759 760 761 |
# File 'lib/aws-sdk-supportapp/client.rb', line 758 def list_slack_workspace_configurations(params = {}, = {}) req = build_request(:list_slack_workspace_configurations, params) req.send_request() end |
#put_account_alias(params = {}) ⇒ Struct
Creates or updates an individual alias for each Amazon Web Services account ID. The alias appears in the Amazon Web Services Support App page of the Amazon Web Services Support Center. The alias also appears in Slack messages from the Amazon Web Services Support App.
783 784 785 786 |
# File 'lib/aws-sdk-supportapp/client.rb', line 783 def put_account_alias(params = {}, = {}) req = build_request(:put_account_alias, params) req.send_request() end |
#register_slack_workspace_for_organization(params = {}) ⇒ Types::RegisterSlackWorkspaceForOrganizationResult
Registers a Slack workspace for your Amazon Web Services account. To call this API, your account must be part of an organization in Organizations.
If you’re the *management account* and you want to register Slack workspaces for your organization, you must complete the following tasks:
-
Sign in to the [Amazon Web Services Support Center] and authorize the Slack workspaces where you want your organization to have access to. See [Authorize a Slack workspace] in the *Amazon Web Services Support User Guide*.
-
Call the ‘RegisterSlackWorkspaceForOrganization` API to authorize each Slack workspace for the organization.
After the management account authorizes the Slack workspace, member accounts can call this API to authorize the same Slack workspace for their individual accounts. Member accounts don’t need to authorize the Slack workspace manually through the [Amazon Web Services Support Center].
To use the Amazon Web Services Support App, each account must then complete the following tasks:
-
Create an Identity and Access Management (IAM) role with the required permission. For more information, see [Managing access to the Amazon Web Services Support App].
-
Configure a Slack channel to use the Amazon Web Services Support App for support cases for that account. For more information, see [Configuring a Slack channel].
[1]: console.aws.amazon.com/support/app [2]: docs.aws.amazon.com/awssupport/latest/user/authorize-slack-workspace.html [3]: docs.aws.amazon.com/awssupport/latest/user/support-app-permissions.html [4]: docs.aws.amazon.com/awssupport/latest/user/add-your-slack-channel.html
855 856 857 858 |
# File 'lib/aws-sdk-supportapp/client.rb', line 855 def register_slack_workspace_for_organization(params = {}, = {}) req = build_request(:register_slack_workspace_for_organization, params) req.send_request() end |
#update_slack_channel_configuration(params = {}) ⇒ Types::UpdateSlackChannelConfigurationResult
Updates the configuration for a Slack channel, such as case update notifications.
961 962 963 964 |
# File 'lib/aws-sdk-supportapp/client.rb', line 961 def update_slack_channel_configuration(params = {}, = {}) req = build_request(:update_slack_channel_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
990 991 992 |
# File 'lib/aws-sdk-supportapp/client.rb', line 990 def waiter_names [] end |